## EC2 Module refactoring

### List of tasks still need to be done

- Dynamic egress / ingress in SGs for any application that needs to be created.
- Customize the root block device configuration
- parametrize useful variables
- subnet id to be set according to what we require.
